==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebSortingOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingOptionsDescription } from "./WebSortingOptionsDescription";
/**
 * @hidden
 */
export let WebSortingOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingOptionsDescriptionMetadata.a == null) {
                WebSortingOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingOptionsDescriptionMetadata.c(WebSortingOptionsDescriptionMetadata.a);
            }
            if (a.j(WebSortingOptionsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSortingOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingOptions");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Mode", "Unknown");
        }
        static d(a) {
            WebSortingOptionsDescriptionMetadata.b(a);
            a.aa("WebSortingOptions", () => new WebSortingOptionsDescription());
            a.z("WebSortingOptions", WebSortingOptionsDescriptionMetadata.a);
        }
    }
    WebSortingOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingOptionsDescriptionMetadata, 'WebSortingOptionsDescriptionMetadata');
    WebSortingOptionsDescriptionMetadata.a = null;
    return WebSortingOptionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebSortingOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingOptionsDescription } from "./WebSortingOptionsDescription";
/**
 * @hidden
 */
export let WebSortingOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingOptionsDescriptionMetadata.a == null) {
                WebSortingOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingOptionsDescriptionMetadata.c(WebSortingOptionsDescriptionMetadata.a);
            }
            if (a.k(WebSortingOptionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSortingOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingOptions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Mode", "Unknown");
        }
        static d(a) {
            WebSortingOptionsDescriptionMetadata.b(a);
            a.ac("WebSortingOptions", () => new WebSortingOptionsDescription());
            a.ab("WebSortingOptions", WebSortingOptionsDescriptionMetadata.a);
        }
    }
    WebSortingOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingOptionsDescriptionMetadata, 'WebSortingOptionsDescriptionMetadata');
    WebSortingOptionsDescriptionMetadata.a = null;
    return WebSortingOptionsDescriptionMetadata;
})();
